Contributing to django-machina
##############################

Thank you for contributing to *django-machina*! A list of simple rules is available on the online
documentation to help you contribute to this project: https://django-machina.readthedocs.org/en/latest/contributing.html
